patch_app

Function patch_app 

pub async fn patch_app(
    configuration: &Configuration,
    app_id: &str,
    app_version: &str,
    req_patch_app: ReqPatchApp,
) -> Result<RespResourceUrl, Error<PatchAppError>>
Update selected attributes of an existing version of an application. Request body may only contain updatable attributes. Application must exist. Attributes that may not be updated via PATCH are - id - owner - enabled - versionEnabled - locked - deleted Note that the attributes owner, enabled, versionEnabled, locked and deleted may be modified using other endpoints.